==> open-xchange-documents-backend_7.8.1.orig.tar.bz2: open-xchange-documents-backend-7.8.1/com.openexchange.office.docx4j/src/main/java/org/docx4j/dml/CTPath2DArcTo.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CT_Path2DArcTo complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_Path2DArcTo">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="wR" use="required" type="{http://schemas.openxmlformats.org/drawingml/2006/main}ST_AdjCoordinate" />
 *       &lt;attribute name="hR" use="required" type="{http://schemas.openxmlformats.org/drawingml/2006/main}ST_AdjCoordinate" />
 *       &lt;attribute name="stAng" use="required" type="{http://schemas.openxmlformats.org/drawingml/2006/main}ST_AdjAngle" />
 *       &lt;attribute name="swAng" use="required" type="{http://schemas.openxmlformats.org/drawingml/2006/main}ST_AdjAngle" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_Path2DArcTo")
public class CTPath2DArcTo {

	@XmlTransient
	protected Object wr;
	@XmlTransient
    protected Object hr;
	@XmlTransient
    protected Object stAng;
	@XmlTransient
    protected Object swAng;

    /**
     * Gets the value of the wr property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @XmlAttribute(name = "wR", required = true)
    public String getWR() {
        return wr.toString();
    }

    /**
     * Sets the value of the wr property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWR(String value) {
        wr = CTAdjPoint2D.getNumberIfPossible(value);
    }

    public Object getParsedWR() {
    	return wr;
    }

    /**
     * Gets the value of the hr property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
	@XmlAttribute(name = "hR", required = true)
    public String getHR() {
        return hr.toString();
    }

    /**
     * Sets the value of the hr property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHR(String value) {
        hr = CTAdjPoint2D.getNumberIfPossible(value);
    }

    public Object getParsedHR() {
    	return hr;
    }

    /**
     * Gets the value of the stAng property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
	@XmlAttribute(required = true)
    public String getStAng() {
        return stAng.toString();
    }

    /**
     * Sets the value of the stAng property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStAng(String value) {
        stAng = CTAdjPoint2D.getNumberIfPossible(value);
    }

    public Object getParsedStAng() {
    	return stAng;
    }

    /**
     * Gets the value of the swAng property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
	@XmlAttribute(required = true)
    public String getSwAng() {
        return swAng.toString();
    }

    /**
     * Sets the value of the swAng property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSwAng(String value) {
        swAng = CTAdjPoint2D.getNumberIfPossible(value);
    }

    public Object getParsedSwAng() {
    	return swAng;
    }
}

==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.docx4j/src/main/java/org/docx4j/dml/CTPath2DArcTo.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CT_Path2DArcTo complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_Path2DArcTo">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="wR" use="required" type="{http://schemas.openxmlformats.org/drawingml/2006/main}ST_AdjCoordinate" />
 *       &lt;attribute name="hR" use="required" type="{http://schemas.openxmlformats.org/drawingml/2006/main}ST_AdjCoordinate" />
 *       &lt;attribute name="stAng" use="required" type="{http://schemas.openxmlformats.org/drawingml/2006/main}ST_AdjAngle" />
 *       &lt;attribute name="swAng" use="required" type="{http://schemas.openxmlformats.org/drawingml/2006/main}ST_AdjAngle" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_Path2DArcTo")
public class CTPath2DArcTo {

	@XmlTransient
	protected Object wr;
	@XmlTransient
    protected Object hr;
	@XmlTransient
    protected Object stAng;
	@XmlTransient
    protected Object swAng;

    /**
     * Gets the value of the wr property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @XmlAttribute(name = "wR", required = true)
    public String getWR() {
        return wr.toString();
    }

    /**
     * Sets the value of the wr property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWR(String value) {
        wr = CTAdjPoint2D.getLongIfPossible(value);
    }

    public Object getParsedWR() {
    	return wr;
    }

    /**
     * Gets the value of the hr property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
	@XmlAttribute(name = "hR", required = true)
    public String getHR() {
        return hr.toString();
    }

    /**
     * Sets the value of the hr property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHR(String value) {
        hr = CTAdjPoint2D.getLongIfPossible(value);
    }

    public Object getParsedHR() {
    	return hr;
    }

    /**
     * Gets the value of the stAng property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
	@XmlAttribute(required = true)
    public String getStAng() {
        return stAng.toString();
    }

    /**
     * Sets the value of the stAng property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStAng(String value) {
        stAng = CTAdjPoint2D.getLongIfPossible(value);
    }

    public Object getParsedStAng() {
    	return stAng;
    }

    /**
     * Gets the value of the swAng property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
	@XmlAttribute(required = true)
    public String getSwAng() {
        return swAng.toString();
    }

    /**
     * Sets the value of the swAng property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSwAng(String value) {
        swAng = CTAdjPoint2D.getLongIfPossible(value);
    }

    public Object getParsedSwAng() {
    	return swAng;
    }
}
